# -*- coding: utf-8 -*-

# django-opensearch
# opensearch/settings.py

from __future__ import unicode_literals

from django.conf import settings

__all__ = [
    "CONTACT_EMAIL",
    "SHORT_NAME",
    "DESCRIPTION",
    "FAVICON_WIDTH",
    "FAVICON_HEIGHT",
    "FAVICON_TYPE",
    "FAVICON_FILE",
    "SEARCH_URL",
]


CONTACT_EMAIL = getattr(settings, "OPENSEARCH_CONTACT_EMAIL", "")
SHORT_NAME = getattr(settings, "OPENSEARCH_SHORT_NAME", "")
DESCRIPTION = getattr(settings, "OPENSEARCH_DESCRIPTION", "")
FAVICON_WIDTH = getattr(settings, "OPENSEARCH_FAVICON_WIDTH", 16)
FAVICON_HEIGHT = getattr(settings, "OPENSEARCH_FAVICON_HEIGHT", 16)
FAVICON_TYPE = getattr(settings, "OPENSEARCH_FAVICON_TYPE", "image/x-icon")
FAVICON_FILE = getattr(settings, "OPENSEARCH_FAVICON_FILE", "favicon.ico")
SEARCH_URL = getattr(settings, "OPENSEARCH_SEARCH_URL", "search")



# -*- coding: utf-8 -*-

# django-opensearch
# opensearch/views.py

from __future__ import unicode_literals

from django.shortcuts import render_to_response
from django.template import RequestContext
from django.core.urlresolvers import reverse

from opensearch import settings

__all__ = ["opensearch", ]


def opensearch(request):
    """
    Return opensearch.xml.
    """

    contact_email = settings.CONTACT_EMAIL
    short_name = settings.SHORT_NAME
    description = settings.DESCRIPTION
    favicon_width = settings.FAVICON_WIDTH
    favicon_height = settings.FAVICON_HEIGHT
    favicon_type = settings.FAVICON_TYPE
    favicon_file = settings.FAVICON_FILE
    url = "{url}?q={{searchTerms}}".format(url=request.build_absolute_uri(reverse(settings.SEARCH_URL)))

    return render_to_response("opensearch/opensearch.xml", locals(), context_instance=RequestContext(request), content_type="application/opensearchdescription+xml")



# -*- coding: utf-8 -*-

# django-opensearch
# opensearch/apps.py

from __future__ import unicode_literals

from django.apps import AppConfig

__all__ = ["OpensearchConfig", ]


class OpensearchConfig(AppConfig):

    name = "opensearch"
    verbose_name = "Django opensearch"



# -*- coding: utf-8 -*-

# django-opensearch
# opensearch/__init__.py

from __future__ import unicode_literals

__all__ = [
    "models",
    "views",
    "url",
    "templatetags",
    "apps",
    "default_app_config",
]

default_app_config = "opensearch.apps.OpensearchConfig"



# -*- coding: utf-8 -*-

# django-opensearch
# opensearch/templatetags/opensearch_tags.py

from __future__ import unicode_literals

from django import template

from opensearch import settings

__all__ = ["opensearch_meta", ]

register = template.Library()


@register.inclusion_tag("opensearch/templatetags/opensearch_meta.html", takes_context=True)
def opensearch_meta(context):
    """
    Return meta rel opensearch tag.
    """

    context.update({
        "DESCRIPTION": settings.DESCRIPTION,
    })

    return context



# -*- coding: utf-8 -*-

# django-opensearch
# opensearch/urls.py

from __future__ import unicode_literals

from django.conf.urls import patterns, url

# opesearch urls
urlpatterns = patterns("opensearch.views",
    url(r"^opensearch\.xml$", "opensearch", name="opensearch"),  # opensearch
)
